# aiodown

> An `asyncio-based` file downloader made in `Python 3` using [httpx](//github.com/encode/httpx).

## Requirements

- Python 3.8 or higher.
- httpx 0.14 or higher.

## Installation

**NOTE:** If `python3` is "not a recognized command" try using `python` instead.<br>
<br>
`python3 -m pip install git+https://github.com/AmanoTeam/aiodown`<br>

## What's left to do?

- Write the API Documentation.
- Show some examples.

## License

MIT © 2021 [AmanoTeam](//github.com/AmanoTeam)